==> packageinstaller-pkglist_0.3.29.tar.xz: packageinstaller-pkglist/Polish_LO_Latest_main.pm <==
<?xml version="1.0"?>
<app>

<category>
Language
</category>

<name>
Polish_LO_Latest_main
</name>

<description>
   <am>Polish Language Meta-Package for LibreOffice</am>
   <ar>Polish Language Meta-Package for LibreOffice</ar>
   <be>Polish Language Meta-Package for LibreOffice</be>
   <bg>Polish Language Meta-Package for LibreOffice</bg>
   <bn>Polish Language Meta-Package for LibreOffice</bn>
   <ca>Meta-paquet de llengua per LibreOffice en Polonès</ca>
   <cs>Polish Language Meta-Package for LibreOffice</cs>
   <da>Polsk sprog-metapakke til LibreOffice</da>
   <de>Polnisches Meta-Paket für LibreOffice</de>
   <el>LibreOffice στα Πολωνικά</el>
   <en>Polish Language Meta-Package for LibreOffice</en>
   <es_ES>Meta-Paquete de Idioma Polaco para LibreOffice</es_ES>
   <es>Metapaquete de Idioma Polaco para LibreOffice</es>
   <et>Polish Language Meta-Package for LibreOffice</et>
   <eu>Polish Language Meta-Package for LibreOffice</eu>
   <fa>Polish Language Meta-Package for LibreOffice</fa>
   <fil_PH>Polish Language Meta-Package for LibreOffice</fil_PH>
   <fi>Puolalainen kielipaketti LibreOffice:lle</fi>
   <fr_BE>Polish Language Meta-Package for LibreOffice</fr_BE>
   <fr>Méta-paquet langue polonaise pour LibreOffice</fr>
   <gl_ES>Polaco Meta-paquete de Idioma para LibreOffice</gl_ES>
   <he_IL>Polish Language Meta-Package for LibreOffice</he_IL>
   <hi>Polish Language Meta-Package for LibreOffice</hi>
   <hr>Polish Language Meta-Package for LibreOffice</hr>
   <hu>Polish Language Meta-Package for LibreOffice</hu>
   <id>Polish Language Meta-Package for LibreOffice</id>
   <is>Polish Language Meta-Package for LibreOffice</is>
   <it>Meta-pacchetto della lingua polacca per LibreOffice</it>
   <ja>LibreOffice用ポーランド語メタパッケージ</ja>
   <kk>Polish Language Meta-Package for LibreOffice</kk>
   <ko>Polish Language Meta-Package for LibreOffice</ko>
   <lt>Polish Language Meta-Package for LibreOffice</lt>
   <mk>Polish Language Meta-Package for LibreOffice</mk>
   <mr>Polish Language Meta-Package for LibreOffice</mr>
   <nb_NO>Polish Language Meta-Package for LibreOffice</nb_NO>
   <nb>Polsk språkpakke for LibreOffice</nb>
   <nl_BE>Polish Language Meta-Package for LibreOffice</nl_BE>
   <nl>Poolse Taal Meta-Pakket voor LibreOffice</nl>
   <pl>Polski metapakiet językowy dla LibreOffice</pl>
   <pt_BR>Polonês Pacote de Idioma para o LibreOffice</pt_BR>
   <pt>Polaco Meta-Pacote de Idioma para LibreOffice</pt>
   <ro>Polish Language Meta-Package for LibreOffice</ro>
   <ru>Polish Language Meta-Package for LibreOffice</ru>
   <sk>Polish Language Meta-Package for LibreOffice</sk>
   <sl>Polish Language Meta-Package for LibreOffice</sl>
   <sq>Polish Language Meta-Package for LibreOffice</sq>
   <sr>Polish Language Meta-Package for LibreOffice</sr>
   <sv>Polskt Språk Meta-Paket för LibreOffice </sv>
   <th>Meta-Package ภาษา Polish สำหรับ LibreOffice</th>
   <tr>LibreOffice için Lehçe Dili Üst-Paketi</tr>
   <uk>Polish Language Meta-Package for LibreOffice</uk>
   <vi>Polish Language Meta-Package for LibreOffice</vi>
   <zh_CN>Polish Language Meta-Package for LibreOffice</zh_CN>
   <zh_HK>Polish Language Meta-Package for LibreOffice</zh_HK>
   <zh_TW>Polish Language Meta-Package for LibreOffice</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>none</screenshot>

<preinstall>
echo "deb http://deb.debian.org/debian buster-backports main contrib non-free">/etc/apt/sources.list.d/pitemp.list
apt-get update
</preinstall>

<install_package_names>
-t buster-backports libreoffice-calc
libreoffice-draw
libreoffice-impress
libreoffice-math
libreoffice-writer
libreoffice-l10n-pl
libreoffice-gtk3
</install_package_names>

<postinstall>
rm /etc/apt/sources.list.d/pitemp.list
apt-get update
</postinstall>

<uninstall_package_names>
libreoffice-calc
libreoffice-draw
libreoffice-impress
libreoffice-math
libreoffice-writer
libreoffice-l10n-pl
libreoffice-gtk3
</uninstall_package_names>

</app>

==> packageinstaller-pkglist_0.3.30.tar.xz: packageinstaller-pkglist/Polish_LO_Latest_main.pm <==
<?xml version="1.0"?>
<app>

<category>
Language
</category>

<name>
Polish_LO_Latest_main
</name>

<description>
   <am>Polish Language Meta-Package for LibreOffice</am>
   <ar>Polish Language Meta-Package for LibreOffice</ar>
   <be>Polish Language Meta-Package for LibreOffice</be>
   <bg>Polish Language Meta-Package for LibreOffice</bg>
   <bn>Polish Language Meta-Package for LibreOffice</bn>
   <ca>Meta-paquet de llengua per LibreOffice en Polonès</ca>
   <cs>Polish Language Meta-Package for LibreOffice</cs>
   <da>Polsk sprog-metapakke til LibreOffice</da>
   <de>Polnisches Meta-Paket für LibreOffice</de>
   <el>LibreOffice στα Πολωνικά</el>
   <en>Polish Language Meta-Package for LibreOffice</en>
   <es_ES>Meta-Paquete de Idioma Polaco para LibreOffice</es_ES>
   <es>Metapaquete de Idioma Polaco para LibreOffice</es>
   <et>Polish Language Meta-Package for LibreOffice</et>
   <eu>Polish Language Meta-Package for LibreOffice</eu>
   <fa>Polish Language Meta-Package for LibreOffice</fa>
   <fil_PH>Polish Language Meta-Package for LibreOffice</fil_PH>
   <fi>Puolalainen kielipaketti LibreOffice:lle</fi>
   <fr_BE>Méta-paquet langue polonaise pour LibreOffice</fr_BE>
   <fr>Méta-paquet langue polonaise pour LibreOffice</fr>
   <gl_ES>Polaco Meta-paquete de Idioma para LibreOffice</gl_ES>
   <he_IL>Polish Language Meta-Package for LibreOffice</he_IL>
   <hi>Polish Language Meta-Package for LibreOffice</hi>
   <hr>Polish Language Meta-Package for LibreOffice</hr>
   <hu>Polish Language Meta-Package for LibreOffice</hu>
   <id>Polish Language Meta-Package for LibreOffice</id>
   <is>Polish Language Meta-Package for LibreOffice</is>
   <it>Meta-pacchetto della lingua polacca per LibreOffice</it>
   <ja>LibreOffice用ポーランド語メタパッケージ</ja>
   <kk>Polish Language Meta-Package for LibreOffice</kk>
   <ko>Polish Language Meta-Package for LibreOffice</ko>
   <lt>Polish Language Meta-Package for LibreOffice</lt>
   <mk>Polish Language Meta-Package for LibreOffice</mk>
   <mr>Polish Language Meta-Package for LibreOffice</mr>
   <nb_NO>Polish Language Meta-Package for LibreOffice</nb_NO>
   <nb>Polsk språkpakke for LibreOffice</nb>
   <nl_BE>Polish Language Meta-Package for LibreOffice</nl_BE>
   <nl>Poolse Taal Meta-Pakket voor LibreOffice</nl>
   <pl>Polski metapakiet językowy dla LibreOffice</pl>
   <pt_BR>Polonês Pacote de Idioma para o LibreOffice</pt_BR>
   <pt>Polaco Meta-Pacote de Idioma para LibreOffice</pt>
   <ro>Polish Language Meta-Package for LibreOffice</ro>
   <ru>Polish Language Meta-Package for LibreOffice</ru>
   <sk>Polish Language Meta-Package for LibreOffice</sk>
   <sl>Polish Language Meta-Package for LibreOffice</sl>
   <sq>Polish Language Meta-Package for LibreOffice</sq>
   <sr>Polish Language Meta-Package for LibreOffice</sr>
   <sv>Polskt Språk Meta-Paket för LibreOffice </sv>
   <th>Meta-Package ภาษา Polish สำหรับ LibreOffice</th>
   <tr>LibreOffice için Lehçe Dili Üst-Paketi</tr>
   <uk>Polish Language Meta-Package for LibreOffice</uk>
   <vi>Polish Language Meta-Package for LibreOffice</vi>
   <zh_CN>Polish Language Meta-Package for LibreOffice</zh_CN>
   <zh_HK>Polish Language Meta-Package for LibreOffice</zh_HK>
   <zh_TW>Polish Language Meta-Package for LibreOffice</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>none</screenshot>

<preinstall>
echo "deb http://deb.debian.org/debian buster-backports main contrib non-free">/etc/apt/sources.list.d/pitemp.list
apt-get update
</preinstall>

<install_package_names>
-t buster-backports libreoffice-calc
libreoffice-draw
libreoffice-impress
libreoffice-math
libreoffice-writer
libreoffice-l10n-pl
libreoffice-gtk3
</install_package_names>

<postinstall>
rm /etc/apt/sources.list.d/pitemp.list
apt-get update
</postinstall>

<uninstall_package_names>
libreoffice-calc
libreoffice-draw
libreoffice-impress
libreoffice-math
libreoffice-writer
libreoffice-l10n-pl
libreoffice-gtk3
</uninstall_package_names>

</app>
